@@ -1,5 +1,5 @@
 /*
- Copyright (c) 2012-2014, CKSource - Frederico Knabben. All rights reserved.
+ Copyright (c) 2012-2021, CKSource - Frederico Knabben. All rights reserved.
  For licensing, see LICENSE.md
  */
 
@@ -295,11 +295,15 @@ CKBuilder.builder = function( srcDir, dstDir ) {
 	 */
 	function filterPluginFolders() {
 		var pluginsFolder = new File( targetLocation, 'plugins' );
+
 		if ( !pluginsFolder.exists() )
 			return;
-		var dirList = pluginsFolder.list();
+
+		var requiredPlugins = CKBuilder.options.requirePlugins ? CKBuilder.options.requirePlugins.split( ',' ) : [],
+			dirList = pluginsFolder.list();
+
 		for ( var i = 0; i < dirList.length; i++ ) {
-			if ( !pluginNames[ dirList[ i ] ] ) {
+			if ( !pluginNames[ dirList[ i ] ] && !includes( requiredPlugins, dirList[ i ] ) ) {
 				if ( CKBuilder.options.debug > 1 )
 					print( 'Removing unused plugin: ' + dirList[ i ] );
 				CKBuilder.io.deleteDirectory( File( pluginsFolder, dirList[ i ] ) );
@@ -307,6 +311,25 @@ CKBuilder.builder = function( srcDir, dstDir ) {
 		}
 	}
 
+	/**
+	 * Check if an array contains given element.
+	 * Alias for Array.prototype.includes method.
+	 *
+	 * @param {Array} array
+	 * @param {String} element
+	 *
+	 * @returns {Boolean}
+	 */
+	function includes( array, element ) {
+		for ( var i = 0; i < array.length; i++ ) {
+			if ( array[ i ] == element ) {
+				return true;
+			}
+		}
+
+		return false;
+	}
+
 	/**
 	 * Remove unused skins (not included in the build configuation file) from the skins folder.
 	 * Executed only when skip-omitted-in-build-config is enabled.
